import matplotlib.pyplot as plt
from enum import Enum, auto
import itertools

class Axis(Enum):
    ABSCISSA = auto()
    ORDINATE = auto()

    def __str__(self):
        return self.name.title()

# TODO: with right color
# TODO: precising somehow low or high
INTERESTING_VALUES_OF_AXES = {
    Axis.ABSCISSA: [0, 30, 60, 84, 108, 132, 160, 179],
    Axis.ORDINATE: [0, 25, 40, 55, 70,  85,  100, 117],
}

halfHeight = height // 2
halfWidth = width // 2
PROFILES_OF_AXES = {
    Axis.ABSCISSA: secondImage[halfHeight , halfWidth:],
    Axis.ORDINATE: secondImage[halfHeight:, halfWidth ],
}

colorsOfAxes = {}

for axis in Axis:
    plt.title('Axis Fourier transform profile')
    plt.xlabel('Fourier transform axis')
    plt.ylabel('Fourier transform logarithmic intensity')
    height, width = secondImage.shape
    axisProfile = PROFILES_OF_AXES[axis]
    colorsOfAxes[axis] = plt.plot(axisProfile, label = axis)[0].get_color()

for axis in Axis:
    for interestingValueOfAxisIndex, interestingValueOfAxis in enumerate(INTERESTING_VALUES_OF_AXES[axis]):
        plt.axvline(interestingValueOfAxis, color = colorsOfAxes[axis], alpha = 0.3, linestyle = ':' if interestingValueOfAxisIndex % 2 == 0 else '--', label = 'Test')

def flattenDictValues(dict_):
    return itertools.chain(*dict_.values())

allInterestingValuesOfAxes = list(set(flattenDictValues(INTERESTING_VALUES_OF_AXES)))
plt.xticks(list(plt.xticks()[0]) + allInterestingValuesOfAxes)

allInterestingValuesOfAxesMin = min(allInterestingValuesOfAxes)
allInterestingValuesOfAxesMax = max(allInterestingValuesOfAxes)
plt.xlim(allInterestingValuesOfAxesMin, allInterestingValuesOfAxesMax)

INTERESTING_PROFILES_OF_AXES = {axis: PROFILES_OF_AXES[axis][allInterestingValuesOfAxesMin:allInterestingValuesOfAxesMax + 1] for axis in Axis}
allInterestingIntensitiesOfAxes = list(flattenDictValues(INTERESTING_PROFILES_OF_AXES))
allInterestingIntensitiesOfAxesMin = min(allInterestingIntensitiesOfAxes)
allInterestingIntensitiesOfAxesMax = max(allInterestingIntensitiesOfAxes)
plt.ylim(allInterestingIntensitiesOfAxesMin, allInterestingIntensitiesOfAxesMax)

plt.legend()
plt.show()